@@ -20,6 +20,7 @@
  
 #include "dialog_invalid_data.h"
 #include <glom/libglom/data_structure/glomconversions.h>
+#include <glom/libglom/utils.h>
 
 namespace Glom
 {
@@ -30,13 +31,24 @@ namespace Glom
 bool glom_show_dialog_invalid_data(Field::glom_field_type glom_type)
 {
   //TODO: Share a global instance, to make this quicker?
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_data_invalid_format");
+#else
+  std::auto_ptr<Gnome::Glade::XmlError> error;
+  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_data_invalid_format", "", error);
+  if(error.get())
+  {
+    std::cerr << "glom_show_dialog_invalid_data() failed: " << error->what() << std::endl;
+    return false;
+  }
+#endif
+
   Dialog_InvalidData* dialog = 0;
   refXml->get_widget_derived("dialog_data_invalid_format", dialog);
   dialog->set_example_data(glom_type);
   //dialog->set_transient_for(*this);
-  int response = dialog->run();
-
+  int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_data_invalid_format");
+  
   delete dialog;
   return (response == 2); //The glade file has a response of 2 for the Revert button.
 }
@@ -59,10 +71,7 @@ void Dialog_InvalidData::set_example_data(Field::glom_field_type glom_type)
   {
     case(Field::TYPE_DATE):
     {
-      Gnome::Gda::Date date = {0, 0, 0};
-      date.day = 31;
-      date.month = 1;
-      date.year = 2005;
+      Glib::Date date(31, Glib::Date::JANUARY, 2005);
       example_text = Conversions::get_text_for_gda_value(glom_type, Gnome::Gda::Value(date));
       break;
     }
