@@ -21,6 +21,8 @@
 #ifndef GLOM_UTILITY_WIDGETS_DATAWIDGET_H
 #define GLOM_UTILITY_WIDGETS_DATAWIDGET_H
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
 #include "placeholder.h"
 #include "layoutwidgetbase.h"
 #include <gtkmm/label.h>
@@ -60,7 +62,9 @@ public:
 
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name);
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field);
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   sharedptr<LayoutItem_Field> offer_field_layout(const sharedptr<const LayoutItem_Field>& start_field);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   /// Get the actual child widget used to show the data:
   Gtk::Widget* get_data_child_widget();
@@ -77,20 +81,31 @@ protected:
 
   //Overrides of default signal handlers:
   void on_widget_edited(); //From Gtk::Entry, or Gtk::CheckButton.
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool on_button_press_event(GdkEventButton* event); //override.
   virtual void on_child_user_requested_layout();
   virtual void on_child_user_requested_layout_properties();
   virtual void on_child_layout_item_added(LayoutWidgetBase::enumType item_type);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
   void on_button_open_details();
   void on_button_select_id();
   void on_button_choose_date();
 
+  // Don't call it on_style_changed, otherwise we would override a virtual
+  // function from Gtk::Widget. We could indeed do that, but we do it with
+  // a normal signal handler, because we have to do it this way anyway in
+  // case default signal handlers have been disabled in glibmm.
+  void on_self_style_changed(const Glib::RefPtr<Gtk::Style>& style);
+
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void on_menupopup_activate_layout(); //override
   virtual void on_menupopup_activate_layout_properties(); //override
   //virtual void on_menupopup_add_item(LayoutWidgetBase::enumType item);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
   App_Glom* get_application();
 
+  void set_child_size_by_field(const sharedptr<const LayoutItem_Field>& field);
   int get_suitable_width(const sharedptr<const LayoutItem_Field>& field_layout);
 
   /** Show a dialog with a Find so that the user can choose an ID value to indicate the related record.
